MNM-package: Multivariate Nonparametric Methods. An Approach Based on Spatial Signs and Ranks.
Description
The package provides multivariate tests, estimates and methods based on the identity score, spatial sign score and spatial rank score. The methods include one and c-sample problems, shape estimation and testing,
linear regression and principal components.Details
ll{
Package: MNM
Type: Package
Version: 0.95-2
Date: 2011-05-18
License: GPL (>= 2)
}
The methods implemented here are mainly described in Oja (2010) and the package can be used to reproduce most of the examples in the book. The book will be refered to as the MNM book.References
Oja, H. (2010), Multivariate Nonparametric Methods with R. An Approach Based on Spatial Signs and Ranks, Springer.