Learn R Programming

MNM (version 0.95-3)

affine.trans: Function For Affine Data Transformation

Description

Function for transformations of the form $Ax + b$ or $A^{1/2}x + b$

Usage

affine.trans(X, A = diag(1, dim(X)[2]), b = rep(0, dim(X)[2]), 
             A.sqrt = FALSE, na.action = na.fail)

Arguments

X
a numeric data frame or matrix with p columns.
A
full rank p times p matrix.
b
numeric vector of length p.
A.sqrt
logical. If TRUE the symmetric square root of A will be used.
na.action
a function which indicates what should happen when the data contain 'NA's. Default is to fail.

Value

  • a matrix.

Examples

Run this code
data(iris)
IRIS <- iris[,1:4]
colMeans(IRIS)
cov(IRIS)
IRIS.trans <- affine.trans(IRIS, solve(cov(IRIS)), colMeans(IRIS),TRUE)
colMeans(IRIS.trans)
cov(IRIS.trans)

Run the code above in your browser using DataLab