Learn R Programming

MNM (version 0.95-0)

anova.mvl1lm: Comparisons between Multivariate Linear Models

Description

Comparisons between nested multivariate linear models fitted by mv.l1lm. The comparison can be based on score type of tests and Wald type of tests.

Usage

## S3 method for class 'mvl1lm':
anova(object, object2 = NULL, test = "Score", ...)

Arguments

Value

  • A list with class 'anovamvl1lm' containing the following components:
  • modelsthe model call(s) of object and object2.
  • methodtype of the test used.
  • statisticvalue of the test statistic.
  • parameterdegrees of freedom.
  • p.valuep-value of the test.

Details

If only object is provided the function tests if all parameters equal zero. If object and object2 are provided the function tests the null hypothesis that the the restricted model (object2) is true. For details see chapter 13 of the MNM book. Note that it is the users responsibility to make sure that the two models are nested and fitted on the same data. For the regular L2 regression anova.mlm provides more options.

References

Oja, H. (2010), Multivariate Nonparametric Methods with R, Springer.

Examples

Run this code
# creating simple data

X <- cbind(rep(1,100),rmvnorm(100,c(0,0,0)) )
B <- matrix(c(4,1,1,0.5,-3,2,2,2),ncol=4, byrow=TRUE)
Y <- X %*% t(B)+ rmvnorm(100,c(0,0), diag(0.2,2))
DAT <- data.frame(x1=X[,2],x2=X[,3], x3=X[,4])

FullModel <- mv.l1lm(Y ~ x1 + x2 + x3, scores= "s", stand="i", data=DAT)
RestModel <- mv.l1lm(Y ~ x1, scores= "s", stand="i", data=DAT)

anova(FullModel)
anova(FullModel, RestModel)
anova(FullModel, RestModel, test="W")

Run the code above in your browser using DataLab