Learn R Programming

MNM (version 0.95-0)

coef.mvl1lm: Coefficients of an mvl1lm Object

Description

Extracts the coefficents of an mvl1lm object.

Usage

## S3 method for class 'mvl1lm':
coef(object, ...)

Arguments

Details

Note that for rank scores the intercept, even when specified in the model, is not considered a coefficient.