Learn R Programming

MNM (version 0.95-0)

mv.2way.est: Treatment Effect Estimates in the Randomized Complete Block Case

Description

The treatment effect estimates for different score functions and their asymptotic covariance matrices in the randomized complete block case.

Usage

mv.2way.est(x, block, treatment, score = c("identity", "sign", "rank"),
             stand = c("outer", "inner"), 
             eps=1.0e-10, n.iter=1000, na.action = na.fail)

Arguments

Value

  • A list of length (treatment-1) with class 'mvcloc'. The ith component of the previous list is a list with class 'mvloc' containing the following components:
  • locationthe treatment effect estimate when comparing the first treatment to the (i+1)th treatment.
  • vcovthe asymptotic covariance matrix of the treatment effect estimate.
  • est.namename of the treatment effect estimate.
  • dnamename of data set for which the treatment effect estimate was computed.

Details

This implements the treatment effect estimates described in chapter 12 of the MNM book.

References

Oja, H. (2010), Multivariate Nonparametric Methods with R, Springer.

See Also

mv.2way.test, mv.1sample.est, mv.2sample.est

Examples

Run this code
data(beans)
est<-mv.2way.est(beans[,3:5],beans$Block,beans$Treatment,score="r",stand="i")
summary(est)

Run the code above in your browser using DataLab