Learn R Programming

MNM (version 0.95-0)

pairs2: Plotting two numeric matrices

Description

The function plots each variable contained in the matrix 'x' against the all variables contained in matrix 'y'. The function is not very sophisticated and only used to consider the residuals in a multivariate regression.

Usage

pairs2(x, y, mars = c(4, 4, 0.1, 0.1), ...)

Arguments

Examples

Run this code
X <- rmvnorm(50, c(0,0,1))
Y <- rmvnorm(50, c(20,1), matrix(rep(0.5,4),ncol=2))
colnames(X) <- LETTERS[1:3]
colnames(Y) <- letters[1:2]
pairs2(X,Y)

Run the code above in your browser using DataLab