Learn R Programming

MNM (version 0.95-2)

predict.mvl1lm: Predicted Values Based on a Model Fitted by mv.l1lm

Description

Predicted response values based on a model fitted by mv.l1lm.

Usage

## S3 method for class 'mvl1lm':
predict(object, newdata, na.action = na.pass, ...)

Arguments

object
an object of class mvl1lm.
newdata
An optional data frame with the values of the explaining variables. If omitted, the fitted values are used.
na.action
function determining what should be done with missing values in 'newdata'.
...
needed for other methods.