Learn R Programming

MNM (version 0.95-2)

rmvpowerexp: Random Samples From a Power Exponential Distributions

Description

Function to obtain random samples from a multivariate power exponential distribution.

Usage

rmvpowerexp(n, Location = rep(0, nrow(Scatter)), 
            Scatter = diag(length(Location)), Beta = 1)

Arguments

n
number of random samples.
Location
Location vector of the distribution.
Scatter
Scatter matrix of the distribution.
Beta
shape parameter of the distribution.

Value

  • a matrix.

Details

The power exponential distribution is an elliptical distribution which can have light or heavy tails. Beta = 1 yields a multivariate normal distribution, Beta = 0.5 the multivariate Laplace distribution and with increasing Beta converges to a multivariate uniform distribution.

References

Oja, H. (2010), Multivariate Nonparametric Methods with R, Springer.

See Also

rmvnorm, rmvt

Examples

Run this code
X1 <- rmvpowerexp(100,c(0,0,0),Beta = 0.5)
pairs(X1)
X2 <- rmvpowerexp(100,c(0,0,0),Beta = 1)
pairs(X2)
X3 <- rmvpowerexp(100,c(0,0,0),Beta = 10)
pairs(X3)

Run the code above in your browser using DataLab