Learn R Programming

MNM (version 0.95-0)

summary.mvl1lm: Summary for an mvl1lm Object

Description

Gives a detailed output for an object of class mvl1lm. Note that the output will differ for different score functions used.

Usage

## S3 method for class 'mvl1lm':
summary(object, ..., digits = 3)

Arguments