A list of length (treatment-1) with class 'mvcloc'.
The ith component of the previous list is a list with class 'mvloc'
containing the following components:
locationthe treatment effect estimate when comparing the first
treatment to the (i+1)th treatment.
vcovthe asymptotic covariance matrix of the treatment effect estimate.
est.namename of the treatment effect estimate.
dnamename of data set for which the treatment effect estimate was computed.
Details
This implements the treatment effect estimates described in
chapter 12 of the MNM book.
References
Oja, H. (2010), Multivariate Nonparametric Methods with R, Springer.