Learn R Programming

MNM (version 0.95-2)

mv.2way.est: Treatment Effect Estimates in the Randomized Complete Block Case

Description

The treatment effect estimates for different score functions and their asymptotic covariance matrices in the randomized complete block case.

Usage

mv.2way.est(x, block, treatment, score = c("identity", "sign", "rank"),
             stand = c("outer", "inner"), 
             eps=1.0e-10, n.iter=1000, na.action = na.fail)

Arguments

x
a numeric data frame or matrix.
block
a factor with at least two levels.
treatment
a factor with at least two levels.
score
the score to be used. Possible choices are identity, sign and rank.
stand
the standardization method used. Possible choices are outer and inner.
eps
convergence criterion.
n.iter
maximum number of iterations.
na.action
a function which indicates what should happen when the data contain 'NA's. Default is to fail.

Value

  • A list of length c(c-1)/2 with class 'mvcloc' where c is the number of treatments. Each component of the list is a list with class 'mvloc' containing the following components:
  • locationthe adjusted treatment effect estimate when comparing the treatment pair given in dname.
  • vcovthe asymptotic covariance matrix of the adjusted treatment effect estimate.
  • est.namename of the adjusted treatment effect estimate.
  • dnamethe treatment pair for which the adjusted treatment effect estimate was computed.

Details

This implements the treatment effect estimates described in chapter 12 of the MNM book.

References

Oja, H. (2010), Multivariate Nonparametric Methods with R, Springer.

See Also

mv.2way.test, mv.1sample.est, mv.2sample.est

Examples

Run this code
data(beans)
est<-mv.2way.est(beans[,3:5],beans$Block,beans$Treatment,score="r",stand="i")
summary(est)

Run the code above in your browser using DataLab