the score to be used. Possible choices are
identity, sign and rank.
stand
the standardization method used. Possible choices
are outer and inner.
eps
convergence criterion.
n.iter
maximum number of iterations.
na.action
a function which indicates what should happen when
the data contain 'NA's. Default is to fail.
Value
A list of length c(c-1)/2 with class 'mvcloc' where c is the number of
treatments. Each component of the list is a list with class 'mvloc'
containing the following components:
locationthe adjusted treatment effect estimate when comparing the
treatment pair given in dname.
vcovthe asymptotic covariance matrix of the adjusted treatment effect estimate.
est.namename of the adjusted treatment effect estimate.
dnamethe treatment pair for which the adjusted treatment effect estimate was computed.
Details
This implements the treatment effect estimates described in
chapter 12 of the MNM book.
References
Oja, H. (2010), Multivariate Nonparametric Methods with R, Springer.